@@ -18,11 +18,17 @@
 #'   vectors will not be printed. This is useful when printing frequency tables
 #'   of all variables from a data frame, and due to computational reasons
 #'   character vectors should not be printed.
+#' @param show.na Logical, or \code{"auto"}. If \code{TRUE}, the output always
+#'   contains informatin on missing values, even if variables have no missing
+#'   values. If \code{FALSE}, information on missing values are removed from
+#'   the output. If \code{show.na = "auto"}, information on missing values
+#'   is only shown when variables actually have missing values, else it's not
+#'   shown.
 #' @param grp.strings Numeric, if not \code{NULL}, groups string values in
-#'   character vectors, based on their similarity. The similarity is estimated
-#'   with the \pkg{stringdist}-package. See \code{\link{group_str}} for details
-#'   on grouping, and that function's \code{maxdist}-argument to get more
-#'   details on the distance of strings to be treated as equal.
+#'   character vectors, based on their similarity. See \code{\link{group_str}}
+#'   and \code{\link{str_find}} for details on grouping, and their
+#'   \code{precision}-argument to get more details on the distance of strings
+#'   to be treated as equal.
 #' @param title String, will be used as alternative title to the variable
 #'   label. If \code{x} is a grouped data frame, \code{title} must be a
 #'   vector of same length as groups.
@@ -78,6 +84,12 @@
 #' efc$weights <- abs(rnorm(n = nrow(efc), mean = 1, sd = .5))
 #' frq(efc, c160age, auto.grp = 5, weights = weights)
 #'
+#' # different weight options
+#' frq(efc, c172code, weights = weights)
+#' frq(efc, c172code, weights = "weights")
+#' frq(efc, c172code, weights = efc$weights)
+#' frq(efc$c172code, weights = efc$weights)
+#'
 #' # group string values
 #' dummy <- efc[1:50, 3, drop = FALSE]
 #' dummy$words <- sample(
@@ -91,7 +103,7 @@
 #' frq(dummy, grp.strings = 2)
 #'
 #' @importFrom stats na.omit
-#' @importFrom dplyr full_join select_if select
+#' @importFrom dplyr full_join select_if select group_keys
 #' @importFrom sjlabelled get_label get_labels get_values copy_labels
 #' @importFrom purrr map_if
 #' @importFrom rlang quo_name enquo
@@ -102,6 +114,7 @@ frq <- function(x,
                 weights = NULL,
                 auto.grp = NULL,
                 show.strings = TRUE,
+                show.na = TRUE,
                 grp.strings = NULL,
                 out = c("txt", "viewer", "browser"),
                 title = NULL,
@@ -131,6 +144,10 @@ frq <- function(x,
     if (!sjmisc::is_empty(w) && w != "NULL" && !obj_has_name(xw, w) && obj_has_name(x, w)) {
       x <- dplyr::bind_cols(xw, data.frame(x[[w]]))
       colnames(x)[ncol(x)] <- w
+    } else if (!sjmisc::is_empty(string_contains("$", w)) && length(w.string) > 1 && is.numeric(w.string)) {
+      x <- cbind(xw, data.frame(w.string))
+      w <- sub("(.*)\\$(.*)", "\\2", w)
+      colnames(x)[ncol(x)] <- w
     } else {
       message(sprintf("Weights `%s` not found in data.", w))
       w <- NULL
@@ -166,23 +183,42 @@ frq <- function(x,
   if (!show.strings)
     x <- dplyr::select_if(x, no_character)
 
-  if (sjmisc::is_empty(x)) return(NULL)
+  if (sjmisc::is_empty(stats::na.omit(x))) return(NULL)
 
 
   # group strings
 
   if (!is.null(grp.strings)) {
+    a <- attributes(x)
+
+    if (!is.data.frame(x)) {
+      was.df <- FALSE
+      x <- data.frame(x, stringsAsFactors = FALSE)
+    } else
+      was.df <- TRUE
+
+
     x <- x %>%
       purrr::map_if(is.character, ~ group_str(
-        strings = .x, maxdist = grp.strings, remove.empty = FALSE)
+        strings = .x, precision = grp.strings, remove.empty = FALSE)
       ) %>%
-      as.data.frame()
+      as.data.frame(stringsAsFactors = FALSE)
+
+    if (was.df)
+      attributes(x) <- a
+    else
+      attributes(x[[1]]) <- a
   }
 
 
   # do we have a grouped data frame?
   if (inherits(x, "grouped_df")) {
 
+    grkey <- colnames(dplyr::group_keys(x))
+    for (i in grkey) {
+      if (is.character(x[[i]])) x[[i]] <- as.factor(x[[i]])
+    }
+
     # get grouped data
     grps <- get_grouped_data(x)
 
@@ -215,7 +251,8 @@ frq <- function(x,
               weight.by = wb,
               cn = colnames(tmp)[1],
               auto.grp = auto.grp,
-              title = gr.title
+              title = gr.title,
+              show.na = show.na
             )
 
           attr(dummy, "group") <- get_grouped_title(x, grps, i, sep = "\n")
@@ -246,7 +283,8 @@ frq <- function(x,
             weight.by = wb,
             cn = colnames(x)[i],
             auto.grp = auto.grp,
-            title = title
+            title = title,
+            show.na = show.na
           )
 
         # save data frame for return value
@@ -273,7 +311,7 @@ frq <- function(x,
 #' @importFrom dplyr n_distinct full_join bind_rows
 #' @importFrom stats na.omit xtabs na.pass sd weighted.mean
 #' @importFrom sjlabelled get_labels get_label as_numeric
-frq_helper <- function(x, sort.frq, weight.by, cn, auto.grp, title = NULL) {
+frq_helper <- function(x, sort.frq, weight.by, cn, auto.grp, title = NULL, show.na = TRUE) {
   # remember type
   vartype <- var_type(x)
 
@@ -464,6 +502,11 @@ frq_helper <- function(x, sort.frq, weight.by, cn, auto.grp, title = NULL) {
   # sort
   if (sort.frq == "none") mydat <- mydat[order(reihe), ]
 
+  # remove NA, if requested
+  has.na <- mydat$frq[nrow(mydat)] > 0
+  if ((!is.logical(show.na) && show.na == "auto" && !has.na) || identical(show.na, FALSE))
+    mydat <- mydat[-nrow(mydat), ]
+
   # add variable label and type as attribute, for print-method
 
   if (!is.null(title)) {
@@ -488,7 +531,7 @@ get_grouped_title <- function(x, grps, i, sep = "\n") {
   title <- sprintf("%s: %s", tp[1], tp[2])
 
   # do we have another groupng variable?
-  if (length(attr(x, "vars", exact = T)) > 1) {
+  if (length(dplyr::group_vars(x)) > 1) {
     tp <- get_title_part(x, grps, 2, i)
     title <- sprintf("%s%s%s: %s", title, sep, tp[1], tp[2])
   }
@@ -526,13 +569,12 @@ get_title_part <- function(x, grps, level, i) {
 }
 
 
-#' @importFrom tidyr nest
-#' @importFrom dplyr filter
+#' @importFrom dplyr filter group_vars
 #' @importFrom stats complete.cases
 #' @importFrom rlang .data
 get_grouped_data <- function(x) {
   # nest data frame
-  grps <- tidyr::nest(x)
+  grps <- .nest(x)
 
   # remove NA category for grouped data
   cc <- grps %>%
@@ -544,7 +586,7 @@ get_grouped_data <- function(x) {
 
   # arrange data
 
-  if (length(attr(x, "vars", exact = T)) == 1)
+  if (length(dplyr::group_vars(x)) == 1)
     reihe <- order(grps[[1]])
   else
     reihe <- order(grps[[1]], grps[[2]])
